@@ -154,10 +154,10 @@ resfiles = [
 	"ref/ClayRGB1998.gam",
 	"ref/sRGB.gam",
 	"ref/verify_extended.ti1",
-	"ti1/d3-e4-s2-g25-m0-b0-f0.ti1",
-	"ti1/d3-e4-s2-g49-m0-b0-f0.ti1",
-	"ti1/d3-e4-s13-g37-m4-b4-f0.ti1",
-	"ti1/d3-e4-s17-g49-m5-b5-f0.ti1",
+	"ti1/d3-e4-s2-g28-m0-b0-f0.ti1",
+	"ti1/d3-e4-s3-g52-m3-b0-f0.ti1",
+	"ti1/d3-e4-s4-g52-m4-b0-f0.ti1",
+	"ti1/d3-e4-s5-g52-m5-b0-f0.ti1",
 	"xrc/extra.xrc",
 	"xrc/gamap.xrc",
 	"xrc/main.xrc",
@@ -187,32 +187,33 @@ untethered_displays = non_argyll_displays + ("Web$", "Chromecast ", "Prisma ",
 virtual_displays = untethered_displays + ("madVR$", )
 
 
-def is_special_display(display_no=None, tests=virtual_displays):
-	display_name = get_display_name(display_no)
+def is_special_display(display=None, tests=virtual_displays):
+	if not isinstance(display, basestring):
+		display = get_display_name(display)
 	for test in tests:
-		if re.match(test, display_name):
+		if re.match(test, display):
 			return True
 	return False
 
 
-def is_uncalibratable_display(display_no=None):
-	return is_special_display(display_no, uncalibratable_displays)
+def is_uncalibratable_display(display=None):
+	return is_special_display(display, uncalibratable_displays)
 
 
-def is_patterngenerator(display_no=None):
-	return is_special_display(display_no, patterngenerators)
+def is_patterngenerator(display=None):
+	return is_special_display(display, patterngenerators)
 
 
-def is_non_argyll_display(display_no=None):
-	return is_special_display(display_no, non_argyll_displays)
+def is_non_argyll_display(display=None):
+	return is_special_display(display, non_argyll_displays)
 
 
-def is_untethered_display(display_no=None):
-	return is_special_display(display_no, untethered_displays)
+def is_untethered_display(display=None):
+	return is_special_display(display, untethered_displays)
 
 
-def is_virtual_display(display_no=None):
-	return is_special_display(display_no, virtual_displays)
+def is_virtual_display(display=None):
+	return is_special_display(display, virtual_displays)
 
 
 def check_3dlut_format(devicename):
@@ -224,7 +225,7 @@ def check_3dlut_format(devicename):
 					getcfg("3dlut.bitdepth.output") == 12)
 
 
-def getbitmap(name, display_missing_icon=True, scale=True):
+def getbitmap(name, display_missing_icon=True, scale=True, use_mask=False):
 	"""
 	Create (if necessary) and return a named bitmap.
 	
@@ -261,17 +262,24 @@ def getbitmap(name, display_missing_icon=True, scale=True):
 			w = int(round(w * scale))
 			h = int(round(h * scale))
 		if parts[-1] == "empty":
-			bitmaps[name] = wx.EmptyBitmap(w, h, depth=-1)
-			dc = wx.MemoryDC()
-			dc.SelectObject(bitmaps[name])
-			dc.SetBackground(wx.Brush("black"))
-			dc.Clear()
-			dc.SelectObject(wx.NullBitmap)
-			bitmaps[name].SetMaskColour("black")
+			if use_mask and sys.platform == "win32":
+				bmp = wx.EmptyBitmap(w, h)
+				bmp.SetMaskColour(wx.Colour(0, 0, 0))
+			else:
+				bmp = wx.EmptyBitmapRGBA(w, h, 255, 0, 255, 0)
 		else:
 			if parts[-1].startswith(appname):
 				parts[-1] = parts[-1].lower()
 			oname = parts[-1]
+			if "#" in oname:
+				# Hex format, RRGGBB or RRGGBBAA
+				oname, color = oname.split("#", 1)
+				parts[-1] = oname
+			else:
+				color = None
+			inverted = oname.endswith("-inverted")
+			if inverted:
+				oname = parts[-1] = oname.split("-inverted")[0]
 			name2x = oname + "@2x"
 			name4x = oname + "@4x"
 			path = None
@@ -323,23 +331,30 @@ def getbitmap(name, display_missing_icon=True, scale=True):
 				if path or scale == 1:
 					break
 			if path:
-				bitmaps[name] = wx.Bitmap(path)
+				bmp = wx.Bitmap(path)
+				if not bmp.IsOk():
+					path = None
+			if path:
+				img = None
 				if scale > 1 and i:
 					rescale = False
 					if i in (1, 2):
 						# HighDPI support. 4x/2x version, determine scaled size
-						w, h = [int(round(v / (2 * (3 - i)) * scale)) for v in bitmaps[name].Size]
+						w, h = [int(round(v / (2 * (3 - i)) * scale)) for v in bmp.Size]
 						rescale = True
 					elif len(size) == 2:
 						# HighDPI support. Icon
 						rescale = True
-					if rescale and (bitmaps[name].Size[0] != w or
-									bitmaps[name].Size[1] != h):
+					if rescale and (bmp.Size[0] != w or
+									bmp.Size[1] != h):
 						# HighDPI support. Rescale
-						img = bitmaps[name].ConvertToImage()
-						if not hasattr(wx, "IMAGE_QUALITY_BILINEAR"):
+						img = bmp.ConvertToImage()
+						if (not hasattr(wx, "IMAGE_QUALITY_BILINEAR") or
+							oname == "list-add"):
+							# In case bilinear is not supported, and to prevent
+							# black borders after resizing for some images
 							quality = wx.IMAGE_QUALITY_NORMAL
-						elif oname == "rgbsquares":
+						elif oname in ():
 							# Hmm. Everything else looks great with bicubic,
 							# but this one gets jaggy unless we use bilinear
 							quality = wx.IMAGE_QUALITY_BILINEAR
@@ -348,20 +363,69 @@ def getbitmap(name, display_missing_icon=True, scale=True):
 						else:
 							quality = wx.IMAGE_QUALITY_BILINEAR
 						img.Rescale(w, h, quality=quality)
-						bitmaps[name] = img.ConvertToBitmap()
-			else:
+				factors = None
+				if (not inverted and len(parts) > 2 and parts[-3] == "icons" and
+					max(wx.SystemSettings.GetColour(wx.SYS_COLOUR_WINDOW)[:3]) < 102):
+					if not img:
+						img = bmp.ConvertToImage()
+					if img.IsBW():
+						inverted = True
+				# Invert after resize (avoids jaggies)
+				if inverted:
+					if not img:
+						img = bmp.ConvertToImage()
+					img.Invert()
+					alpha = wx.SystemSettings.GetColour(wx.SYS_COLOUR_BTNTEXT).alpha
+					if oname in ["applications-system", "color",
+								 "document-open", "document-save-as",
+								 "edit-delete", "image-x-generic", "info",
+								 "install", "list-add", "package-x-generic",
+								 "question", "rgbsquares",
+								 "stock_3d-color-picker", "stock_lock",
+								 "stock_lock-open", "stock_refresh", "web",
+								 "window-center", "zoom-best-fit", "zoom-in",
+								 "zoom-original", "zoom-out"]:
+						# Scale 85 to 255 and adjust alpha
+						factors = (3, 3, 3, alpha / 255.0)
+					else:
+						# Only adjust alpha
+						factors = (1, 1, 1, alpha / 255.0)
+				if color or factors:
+					if not img:
+						img = bmp.ConvertToImage()
+					if color:
+						# Hex format, RRGGBB or RRGGBBAA
+						R = int(color[0:2], 16) / 255.0
+						G = int(color[2:4], 16) / 255.0
+						B = int(color[4:6], 16) / 255.0
+						if len(color) > 6:
+							alpha = int(color[6:8], 16) / 255.0
+						else:
+							alpha = 1.0
+					else:
+						R, G, B = factors[:3]
+						if len(factors) > 3:
+							alpha = factors[3]
+						else:
+							alpha = 1.0
+					img = img.AdjustChannels(R, G, B, alpha)
+				if img:
+					bmp = img.ConvertToBitmap()
+					if not bmp.IsOk():
+						path = None
+			if not path:
 				img = wx.EmptyImage(w, h)
 				img.SetMaskColour(0, 0, 0)
 				img.InitAlpha()
 				bmp = img.ConvertToBitmap()
-				bitmaps[name] = bmp
 				dc = wx.MemoryDC()
-				dc.SelectObject(bitmaps[name])
+				dc.SelectObject(bmp)
 				if display_missing_icon:
-					bmp = wx.ArtProvider.GetBitmap(wx.ART_MISSING_IMAGE,
+					art = wx.ArtProvider.GetBitmap(wx.ART_MISSING_IMAGE,
 												   size=(w, h))
-					dc.DrawBitmap(bmp, 0, 0, True)
+					dc.DrawBitmap(art, 0, 0, True)
 				dc.SelectObject(wx.NullBitmap)
+		bitmaps[name] = bmp
 	return bitmaps[name]
 
 
@@ -439,9 +503,11 @@ def get_display_number(display_no):
 	except IndexError:
 		return 0
 	else:
+		if display.endswith(" [PRIMARY]"):
+			display = " ".join(display.split(" ")[:-1])
 		for i in xrange(wx.Display.GetCount()):
 			geometry = "%i, %i, %ix%i" % tuple(wx.Display(i).Geometry)
-			if display.find("@ " + geometry) > -1:
+			if display.endswith("@ " + geometry):
 				if debug:
 					from log import safe_print
 					safe_print("[D] Found display %s at index %i" % 
@@ -465,6 +531,15 @@ def get_icon_bundle(sizes, name):
 	""" Return a wx.IconBundle with given icon sizes """
 	from wxaddons import wx
 	iconbundle = wx.IconBundle()
+	if not sizes:
+		# Assume ICO format
+		pth = get_data_path("theme/icons/%s.ico" % name)
+		if pth:
+			ico = wx.Icon(pth)
+			if ico.IsOk():
+				iconbundle.AddIcon(ico)
+				return iconbundle
+		sizes = [16]
 	for size in sizes:
 		iconbundle.AddIcon(get_bitmap_as_icon(size, name, False))
 	return iconbundle
@@ -491,10 +566,11 @@ def get_measureframe_dimensions(dimensions_measureframe=None, percent=10):
 	return ",".join([str(min(n, 50)) for n in dimensions_measureframe])
 
 
-def geticon(size, name, scale=True):
+def geticon(size, name, scale=True, use_mask=False):
 	""" Convenience function for getbitmap('theme/icons/<size>/<name>'). """
 	return getbitmap("theme/icons/%(size)sx%(size)s/%(name)s" % 
-					 {"size": size, "name": name}, scale=scale)
+					 {"size": size, "name": name}, scale=scale,
+					 use_mask=use_mask)
 
 
 def get_data_path(relpath, rex=None):
@@ -568,7 +644,7 @@ def runtimeconfig(pyfile):
 	
 	"""
 	from log import setup_logging
-	setup_logging(logdir, pyname, pyext)
+	setup_logging(logdir, pyname, pyext, confighome=confighome)
 	if debug or verbose >= 1:
 		from log import safe_print
 	if debug:
@@ -626,7 +702,9 @@ cfg = ConfigParser.RawConfigParser()
 cfg.optionxform = str
 
 valid_ranges = {
-	"3dlut.hdr_peak_luminance": [120, 10000],
+	"3dlut.hdr_peak_luminance": [120.0, 10000.0],
+	"3dlut.hdr_minmll": [0.0, 0.1],
+	"3dlut.hdr_maxmll": [120.0, 10000.0],
 	"3dlut.trc_gamma": [0.000001, 10],
 	"3dlut.trc_output_offset": [0.0, 1.0],
 	"app.port": [1, 65535],
@@ -643,8 +721,11 @@ valid_ranges = {
 	"measurement_report.trc_output_offset": [0.0, 1.0],
 	"measure.display_settle_time_mult": [0.000001, 10000.0],
 	"measure.min_display_update_delay_ms": [20, 60000],
+	"multiprocessing.max_cpus": [0, 65],
 	"patterngenerator.apl": [0.0, 1.0],
+	"patterngenerator.quantize_bits": [0, 32],
 	"patterngenerator.resolve.port": [1, 65535],
+	"profile_loader.quantize_bits": [8, 16],
 	"synthprofile.trc_gamma": [0.01, 10],
 	"synthprofile.trc_output_offset": [0.0, 1.0],
 	"tc_export_repeat_patch_max": [1, 1000],
@@ -652,6 +733,10 @@ valid_ranges = {
 	"tc_vrml_black_offset": [0, 40],
 	"webserver.portnumber": [1, 65535],
 	"whitepoint.colortemp": [1000, 15000],
+	"whitepoint.visual_editor.bg_v": [0, 255],
+	"whitepoint.visual_editor.b": [0, 255],
+	"whitepoint.visual_editor.g": [0, 255],
+	"whitepoint.visual_editor.r": [0, 255],
 }
 
 valid_values = {
@@ -664,11 +749,12 @@ valid_values = {
 									video_encodings),
 	"3dlut.format": ["3dl", "cube", "eeColor", "icc", "madVR", "mga", "png",
 					 "ReShade", "spi3d"],
+	"3dlut.hdr_display": [0, 1],
 	"3dlut.image.layout": ["h", "v"],
 	"3dlut.image.order": ["rgb", "bgr"],
 	"3dlut.rendering_intent": intents,
 	"3dlut.size": [5, 9, 16, 17, 24, 32, 33, 64, 65],
-	"3dlut.trc": ["bt1886", "customgamma", "gamma2.2", "smpte2084.hardclip", "smpte2084.rolloffclip"],
+	"3dlut.trc": ["bt1886", "customgamma", "gamma2.2", "smpte2084.hardclip", "smpte2084.rolloffclip", "hlg"],
 	"3dlut.trc_gamma_type": ["b", "B"],
 	"calibration.quality": ["v", "l", "m", "h", "u"],
 	"colorimeter_correction.observer": observers,
@@ -690,24 +776,32 @@ valid_values = {
 	"gamap_out_viewcond": ["mt", "mb", "md", "jm", "jd"],
 	"measurement_report.trc_gamma_type": ["b", "B"],
 	"observer": observers,
+	"patterngenerator.detect_video_levels": [0, 1],
 	"patterngenerator.prisma.preset": ["Movie", "Sports", "Game", "Animation",
 									   "PC/Mac", "Black+White", "Custom-1",
 									   "Custom-2"],
-	"patterngenerator.resolve.use_video_levels": [0, 1],
+	"patterngenerator.use_video_levels": [0, 1],
 	"profile.black_point_compensation": [0, 1],
 	"profile.install_scope": ["l", "u"],
 	"profile.quality": ["l", "m", "h", "u"],
 	"profile.quality.b2a": ["l", "m", "h", "u", "n", None],
 	"profile.b2a.hires.size": [-1, 9, 17, 33, 45, 65],
 	"profile.type": ["g", "G", "l", "s", "S", "x", "X"],
+	"profile_loader.tray_icon_animation_quality": [0, 1, 2],
 	"synthprofile.black_point_compensation": [0, 1],
 	"synthprofile.trc_gamma_type": ["g", "G"],
 	"tc_algo": ["", "t", "r", "R", "q", "Q", "i", "I"],  # Q = Argyll >= 1.1.0
 	"tc_vrml_use_D50": [0, 1],
 	"tc_vrml_cie_colorspace": ["DIN99", "DIN99b", "DIN99c", "DIN99d", "ICtCp",
-							   "LCH(ab)", "LCH(uv)", "Lab", "Luv", "Lu'v'", "xyY"],
+							   "IPT", "LCH(ab)", "LCH(uv)", "Lab", "Lpt", "Luv",
+							   "Lu'v'", "xyY"],
 	"tc_vrml_device_colorspace": ["HSI", "HSL", "HSV", "RGB"],
-	"testchart.auto_optimize": [0, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18],
+	"testchart.auto_optimize": range(19),
+	"testchart.patch_sequence": ["optimize_display_response_delay",
+								 "maximize_lightness_difference",
+								 "maximize_rec709_luma_difference",
+								 "maximize_RGB_difference",
+								 "vary_RGB_difference"],
 	"trc": ["240", "709", "l", "s", ""],
 	"trc.type": ["g", "G"],
 	"uniformity.cols": [3, 5, 7, 9],
@@ -746,8 +840,11 @@ defaults = {
 	"3dlut.encoding.output.backup": "n",
 	"3dlut.format": "cube",
 	"3dlut.gamap.use_b2a": 0,
-	"3dlut.hdr_maxcll": 10000,
-	"3dlut.hdr_peak_luminance": 400,
+	"3dlut.hdr_display": 0,
+	"3dlut.hdr_minmll": 0.0,
+	"3dlut.hdr_maxmll": 10000.0,
+	"3dlut.hdr_peak_luminance": 400.0,
+	"3dlut.hdr_ambient_luminance": 5.0,
 	"3dlut.image.layout": "h",
 	"3dlut.image.order": "rgb",
 	"3dlut.input.profile": "",
@@ -755,11 +852,14 @@ defaults = {
 	"3dlut.enable": 1,
 	"3dlut.output.profile": "",
 	"3dlut.output.profile.apply_cal": 1,
+	"3dlut.preserve_sync": 0,
 	"3dlut.rendering_intent": "aw",
 	"3dlut.use_abstract_profile": 0,
 	"3dlut.size": 65,
 	"3dlut.tab.enable": 0,
 	"3dlut.tab.enable.backup": 0,
+	"3dlut.whitepoint.x": 0.3127,
+	"3dlut.whitepoint.y": 0.329,
 	"allow_skip_sensor_cal": 0,
 	"app.allow_network_clients": 0,
 	"app.dpi": get_default_dpi(),
@@ -793,6 +893,7 @@ defaults = {
 	"calibration.update": 0,
 	"calibration.use_video_lut": 1,
 	"calibration.use_video_lut.backup": 1,
+	"ccmx.use_four_color_matrix_method": 0,
 	"colorimeter_correction.instrument": None,
 	"colorimeter_correction.instrument.reference": None,
 	"colorimeter_correction.measurement_mode": "l",
@@ -808,10 +909,11 @@ defaults = {
 	"comport.number": 1,
 	"comport.number.backup": 1,
 	# Note: worker.Worker.enumerate_displays_and_ports() overwrites copyright
-	"copyright": "No copyright. Created with %s %s and Argyll CMS" % (appname, 
-																	  version),
+	"copyright": "No copyright. Created with %s %s and ArgyllCMS" % (appname, 
+																	 version),
 	"dimensions.measureframe": "0.5,0.5,1.5",
 	"dimensions.measureframe.unzoomed": "0.5,0.5,1.5",
+	"dimensions.measureframe.whitepoint.visual_editor": "0.5,0.5,1.5",
 	"display.number": 1,
 	"display_lut.link": 1,
 	"display_lut.number": 1,
@@ -832,7 +934,7 @@ defaults = {
 	"gamap_saturation_intent": "s",
 	"gamap_default_intent": "p",
 	"gamma": 2.2,
-	"iccgamut.surface_detail": 6.0,
+	"iccgamut.surface_detail": 10.0,
 	"instruments": "",
 	"last_launch": "99",
 	"log.autoshow": 0,
@@ -878,17 +980,19 @@ defaults = {
 	"measure.override_display_settle_time_mult.backup": 0,
 	"measure.override_min_display_update_delay_ms": 0,
 	"measure.override_min_display_update_delay_ms.backup": 0,
+	"multiprocessing.max_cpus": 0,
 	"observer": "1931_2",
 	"observer.backup": "1931_2",
 	"patterngenerator.apl": .22,
+	"patterngenerator.detect_video_levels": 1,
 	"patterngenerator.prisma.argyll": 0,
 	"patterngenerator.prisma.host": "",
 	"patterngenerator.prisma.preset": "Custom-1",
 	"patterngenerator.prisma.port": 80,
-	"patterngenerator.prisma.use_video_levels": 1,
+	"patterngenerator.quantize_bits": 0,
 	"patterngenerator.resolve": "CM",
 	"patterngenerator.resolve.port": 20002,
-	"patterngenerator.resolve.use_video_levels": 0,
+	"patterngenerator.use_video_levels": 0,
 	"position.x": 50,
 	"position.y": 50,
 	"position.info.x": 50,
@@ -909,7 +1013,10 @@ defaults = {
 	"position.synthiccframe.y": 50,
 	"position.tcgen.x": 50,
 	"position.tcgen.y": 50,
-	"profile.black_point_compensation": 0,
+	# Force black point compensation due to OS X
+	# bugs with non BPC profiles
+	"profile.black_point_compensation": 0 if sys.platform != "darwin" else 1,
+	"profile.black_point_correction": 0.0,
 	"profile.create_gamut_views": 1,
 	"profile.install_scope": "l" if (sys.platform != "win32" and 
 									 os.geteuid() == 0) # or 
@@ -938,12 +1045,17 @@ defaults = {
 	"profile.b2a.hires.size": -1,
 	"profile.b2a.hires.smooth": 1,
 	"profile.save_path": storage, # directory
-	"profile.type": "X",
+	# Force profile type to single shaper + matrix
+	# due to OS X bugs with cLUT profiles and
+	# matrix profiles with individual shaper curves
+	"profile.type": "X" if sys.platform != "darwin" else "S",
 	"profile.update": 0,
-	"profile_loader.check_gamma_ramps": 0,
+	"profile_loader.buggy_video_drivers":  ";".join(["*"]),
+	"profile_loader.check_gamma_ramps": 1,
 	"profile_loader.error.show_msg": 1,
 	"profile_loader.exceptions": "",
-	"profile_loader.fix_profile_associations": 0,
+	"profile_loader.fix_profile_associations": 1,
+	"profile_loader.ignore_unchanged_gamma_ramps": 1,
 	"profile_loader.known_apps": ";".join(["basiccolor display.exe",
 										   "calclient.exe",
 										   "coloreyes display pro.exe",
@@ -955,6 +1067,7 @@ defaults = {
 										   "hp_dreamcolor_calibration_solution.exe",
 										   "i1profiler.exe",
 										   "icolordisplay.exe",
+										   "spectraview.exe",
 										   "spectraview profiler.exe",
 										   "spyder3elite.exe",
 										   "spyder3express.exe",
@@ -967,9 +1080,15 @@ defaults = {
 										   "spyder5pro.exe",
 										   "dispcal.exe",
 										   "dispread.exe",
-										   "flux.exe"]),
+										   "dispwin.exe",
+										   "flux.exe",
+										   "dccw.exe"]),
 	"profile_loader.known_window_classes": ";".join(["CalClient.exe"]),
+	"profile_loader.quantize_bits": 16,
 	"profile_loader.reset_gamma_ramps": 0,
+	"profile_loader.show_notifications": 0,
+	"profile_loader.track_other_processes": 1,
+	"profile_loader.tray_icon_animation_quality": 2,
 	"profile_loader.use_madhcnet": 0,
 	"profile_loader.verify_calibration": 0,
 	"recent_cals": "",
@@ -1038,9 +1157,13 @@ defaults = {
 	"tc_vrml_use_D50": 0,
 	"tc_white_patches": 4,
 	"tc.show": 0,
-	"testchart.auto_optimize": 5,
+	# Profile type forced to matrix due to
+	# OS X bugs with cLUT profiles. Set
+	# smallest testchart.
+	"testchart.auto_optimize": 4 if sys.platform != "darwin" else 1,
 	"testchart.file": "auto",
 	"testchart.file.backup": "auto",
+	"testchart.patch_sequence": "optimize_display_response_delay",
 	"testchart.reference": "",
 	"ti3.check_sanity.auto": 0,
 	"trc": 2.2,
@@ -1061,13 +1184,17 @@ defaults = {
 	"use_separate_lut_access": 0,
 	"vrml.compress": 1,
 	"webserver.portnumber": 8080,
-	"whitepoint.colortemp": 5000,
-	"whitepoint.colortemp.backup": 5000,
+	"whitepoint.colortemp": 6500,
+	"whitepoint.colortemp.backup": 6500,
 	"whitepoint.colortemp.locus": "t",
-	"whitepoint.x": 0.345741,
-	"whitepoint.x.backup": 0.345741,
-	"whitepoint.y": 0.358666,
-	"whitepoint.y.backup": 0.358666,
+	"whitepoint.visual_editor.bg_v": 255,
+	"whitepoint.visual_editor.b": 255,
+	"whitepoint.visual_editor.g": 255,
+	"whitepoint.visual_editor.r": 255,
+	"whitepoint.x": 0.3127,
+	"whitepoint.x.backup": 0.3127,
+	"whitepoint.y": 0.3290,
+	"whitepoint.y.backup": 0.3290,
 	"x3dom.cache": 1,
 	"x3dom.embed": 0
 }
@@ -1265,7 +1392,7 @@ def get_display_profile(display_no=None):
 	except Exception, exception:
 		from log import _safe_print, log
 		_safe_print("ICCP.get_display_profile(%s):" % display_no, 
-					exception, fn=log)
+					safe_unicode(exception), fn=log)
 
 
 standard_profiles = []
@@ -1295,7 +1422,7 @@ def get_standard_profiles(paths_only=False):
 						filename.startswith("gracol") or
 						filename.startswith("iso") or
 						filename.startswith("lstar-") or
-						filename.startswith("pso_") or
+						filename.startswith("pso") or
 						filename.startswith("prophoto") or
 						filename.startswith("psr_") or
 						filename.startswith("psrgravure") or
@@ -1494,9 +1621,10 @@ def initcfg(module=None):
 		setcfg("calibration.file", defaults["calibration.file"])
 	# Read cfg
 	cfgnames = []
-	if module != "3DLUT-maker" and (module != "apply-profiles" or
-									sys.platform != "win32"):
-		# Never read base app cfg for 3D LUT maker or for Windows profile loader
+	if module not in ("3DLUT-maker", "VRML-to-X3D-converter",
+					  "scripting-client"):
+		# Never read base app cfg for 3D LUT maker, VRML converter and
+		# scripting client
 		cfgnames.append(appbasename)
 	if module:
 		cfgnames.append(cfgbasename)
@@ -1514,7 +1642,10 @@ def initcfg(module=None):
 				cfgfiles.append(cfgfile)
 				# Make user config take precedence
 				break
-	cfgfiles.sort(key=lambda cfgfile: os.stat(cfgfile).st_mtime)
+	if len(cfgfiles) > 1 and (module != "apply-profiles" or
+							  sys.platform != "win32"):
+		# Make most recent file take precedence
+		cfgfiles.sort(key=lambda cfgfile: os.stat(cfgfile).st_mtime)
 	try:
 		cfg.read(cfgfiles)
 		# This won't raise an exception if the file does not exist, only
@@ -1659,3 +1790,10 @@ def writecfg(which="user", worker=None, module=None, options=()):
 
 _init_testcharts()
 runtype = runtimeconfig(pyfile)
+
+if isapp and not os.getenv("SSL_CERT_FILE"):
+	# Use our bundled CA file
+	# https://github.com/certifi/python-certifi/blob/master/certifi/cacert.pem
+	cafile = get_data_path("cacert.pem")
+	if cafile:
+		os.environ["SSL_CERT_FILE"] = cafile.encode(fs_enc, "replace")
