@@ -15,7 +15,9 @@ except ImportError:
 	build = lastmod = "0000-00-00T00:00:00.0Z"
 	VERSION = None
 
-if not VERSION or "--test-update" in sys.argv[1:]:
+from options import test_update
+
+if not VERSION or test_update:
 	VERSION = VERSION_BASE = (0, 0, 0, 0)
 	VERSION_STRING = ".".join(str(n) for n in VERSION)
 
@@ -51,7 +53,7 @@ version_short = re.sub("(?:\.0){1,2}$", "", version)
 
 version_tuple = VERSION # only ints allowed and must be exactly 4 values
 
-wx_minversion = (2, 8, 8)
+wx_minversion = (3, 0, 0)
 
 
 def script2pywname(script):
